@@ -58,6 +58,8 @@ private Q_SLOTS:
         QTest::newRow("flixbus") << s("flixbus") << s("flixbus.json") << 53.153505f << 8.274373f << 26.777f << NAN;
         QTest::newRow("sncf-inoui") << s("sncf-tgv") << s("sncf-inoui.json") << 48.064258333f << 7.33914f << 105.379f << 212.5f;
         QTest::newRow("thalys") << s("icomera-omboard") << s("thalys.json") << 50.948208f << 6.885135f << 163.512f << 259.72f;
+        QTest::newRow("oebb-railnet") << s("oebb") << s("oebb-railnet.json") << 47.4719f << 19.022648f << NAN << NAN;
+        QTest::newRow("oebb-railnetregio") << s("oebb") << s("oebb-railnetregio.json") << 48.1459f << 16.4267f << 37.325f  << NAN;
 
         QTest::newRow("ana") << s("panasonic-inflight-v1") << s("../onboard-journey/ana.in.json") << 39.3520f << 141.077f << 801.916f << 191.0f;
         QTest::newRow("united") << s("panasonic-inflight-v1") << s("../onboard-journey/united.in.json") << 41.5150f << 2.069f << 872.292f << 169.0f;
@@ -107,6 +109,7 @@ private Q_SLOTS:
         QTest::newRow("db-zugportal-canceled") << s("deutschebahn-zugportal") << s("db-zugportal-canceled");
         QTest::newRow("sncf-inoui") << s("sncf-tgv") << s("sncf-inoui");
         QTest::newRow("sbb") << s("sbb") << s("sbb");
+        QTest::newRow("oebb-railnet") << s("oebb") << s("oebb-railnet");
 
         QTest::newRow("ana") << s("panasonic-inflight-v1") << s("ana");
         QTest::newRow("united") << s("panasonic-inflight-v1") << s("united");
